Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(7269)

Unified Diff: chrome/browser/ui/browser_window.h

Issue 2754383004: Rename WebsiteSettings code to PageInfo. (Closed)
Patch Set: Upload missing comment fix for WebSettingsUI -> PageInfoUI. Created 3 years, 9 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « chrome/browser/ui/browser_dialogs.h ('k') | chrome/browser/ui/cocoa/browser_window_cocoa.h » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: chrome/browser/ui/browser_window.h
diff --git a/chrome/browser/ui/browser_window.h b/chrome/browser/ui/browser_window.h
index 9394cb955740e52edd8b9ff9bb09391c09e49ab8..25ded9161b5470971f8520c6f4d309c15f777d7d 100644
--- a/chrome/browser/ui/browser_window.h
+++ b/chrome/browser/ui/browser_window.h
@@ -294,11 +294,11 @@ class BrowserWindow : public ui::BaseWindow {
// that it's time to redraw everything.
virtual void UserChangedTheme() = 0;
// Shows the website settings using the specified information. |virtual_url|
// is the virtual url of the page/frame the info applies to, |ssl| is the SSL
// information for that page/frame. If |show_history| is true, a section
// showing how many times that URL has been visited is added to the page info.
- virtual void ShowWebsiteSettings(
+ virtual void ShowPageInfo(
Profile* profile,
content::WebContents* web_contents,
const GURL& virtual_url,
@@ -294,11 +294,11 @@ class BrowserWindow : public ui::BaseWindow {
// that it's time to redraw everything.
virtual void UserChangedTheme() = 0;
- // Shows the website settings using the specified information. |virtual_url|
+ // Shows Page Info using the specified information. |virtual_url|
// is the virtual url of the page/frame the info applies to, |ssl| is the SSL
// information for that page/frame. If |show_history| is true, a section
« no previous file with comments | « chrome/browser/ui/browser_dialogs.h ('k') | chrome/browser/ui/cocoa/browser_window_cocoa.h » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698